summaryrefslogtreecommitdiff
path: root/lib_nios
diff options
context:
space:
mode:
authorWolfgang Denk <wd@denx.de>2008-10-18 21:59:44 +0200
committerWolfgang Denk <wd@denx.de>2008-10-18 21:59:44 +0200
commitf82642e33899766892499b163e60560fbbf87773 (patch)
treeab90f076f18e56b2b3e8c9375b95917daa78c1d9 /lib_nios
parentb59b16ca24bc7e77ec113021a6d77b9b32fcf192 (diff)
parent360fe71e82b83e264c964c9447c537e9a1f643c8 (diff)
downloadu-boot-imx-f82642e33899766892499b163e60560fbbf87773.zip
u-boot-imx-f82642e33899766892499b163e60560fbbf87773.tar.gz
u-boot-imx-f82642e33899766892499b163e60560fbbf87773.tar.bz2
Merge 'next' branch
Conflicts: board/freescale/mpc8536ds/mpc8536ds.c include/configs/mgcoge.h Signed-off-by: Wolfgang Denk <wd@denx.de>
Diffstat (limited to 'lib_nios')
-rw-r--r--lib_nios/board.c22
-rw-r--r--lib_nios/mult.c4
2 files changed, 13 insertions, 13 deletions
diff --git a/lib_nios/mult.c b/lib_nios/mult.c
index 66bb64d..ec8139e 100644
--- a/lib_nios/mult.c
+++ b/lib_nios/mult.c
@@ -20,7 +20,7 @@
#include <common.h>
-#if !defined(CFG_NIOS_MULT_HW) && !defined(CFG_NIOS_MULT_MSTEP)
+#if !defined(CONFIG_SYS_NIOS_MULT_HW) && !defined(CONFIG_SYS_NIOS_MULT_MSTEP)
#include "math.h"
@@ -53,4 +53,4 @@ UHItype __mulhi3 (UHItype a, UHItype b)
return c;
}
-#endif /*!defined(CFG_NIOS_MULT_HW) && !defined(CFG_NIOS_MULT_MSTEP) */
+#endif /*!defined(CONFIG_SYS_NIOS_MULT_HW) && !defined(CONFIG_SYS_NIOS_MULT_MSTEP) */
diff --git a/lib_nios/board.c b/lib_nios/board.c
index cdaf753..024beb5 100644
--- a/lib_nios/board.c
+++ b/lib_nios/board.c
@@ -63,8 +63,8 @@ static ulong mem_malloc_brk = 0;
*/
static void mem_malloc_init (void)
{
- mem_malloc_start = CFG_MALLOC_BASE;
- mem_malloc_end = mem_malloc_start + CFG_MALLOC_LEN;
+ mem_malloc_start = CONFIG_SYS_MALLOC_BASE;
+ mem_malloc_end = mem_malloc_start + CONFIG_SYS_MALLOC_LEN;
mem_malloc_brk = mem_malloc_start;
memset ((void *) mem_malloc_start,
0,
@@ -113,25 +113,25 @@ void board_init (void)
int i;
/* Pointer is writable since we allocated a register for it.
* Nios treats CFG_GBL_DATA_OFFSET as an address.
*/
- gd = (gd_t *)CFG_GBL_DATA_OFFSET;
+ gd = (gd_t *)CONFIG_SYS_GBL_DATA_OFFSET;
/* compiler optimization barrier needed for GCC >= 3.4 */
__asm__ __volatile__("": : :"memory");
- memset( gd, 0, CFG_GBL_DATA_SIZE );
+ memset( gd, 0, CONFIG_SYS_GBL_DATA_SIZE );
gd->bd = (bd_t *)(gd+1); /* At end of global data */
gd->baudrate = CONFIG_BAUDRATE;
gd->cpu_clk = CONFIG_SYS_CLK_FREQ;
bd = gd->bd;
- bd->bi_memstart = CFG_SDRAM_BASE;
- bd->bi_memsize = CFG_SDRAM_SIZE;
- bd->bi_flashstart = CFG_FLASH_BASE;
-#if defined(CFG_SRAM_BASE) && defined(CFG_SRAM_SIZE)
- bd->bi_sramstart= CFG_SRAM_BASE;
- bd->bi_sramsize = CFG_SRAM_SIZE;
+ bd->bi_memstart = CONFIG_SYS_SDRAM_BASE;
+ bd->bi_memsize = CONFIG_SYS_SDRAM_SIZE;
+ bd->bi_flashstart = CONFIG_SYS_FLASH_BASE;
+#if defined(CONFIG_SYS_SRAM_BASE) && defined(CONFIG_SYS_SRAM_SIZE)
+ bd->bi_sramstart= CONFIG_SYS_SRAM_BASE;
+ bd->bi_sramsize = CONFIG_SYS_SRAM_SIZE;
#endif
bd->bi_baudrate = CONFIG_BAUDRATE;
@@ -113,25 +113,25 @@ void board_init (void)
int i;
/* Pointer is writable since we allocated a register for it.
- * Nios treats CFG_GBL_DATA_OFFSET as an address.
+ * Nios treats CONFIG_SYS_GBL_DATA_OFFSET as an address.
*/